@@ -1,14 +1,43 @@
-use strict;
-use warnings;
 package Email::Simple::Header;
-{
-  $Email::Simple::Header::VERSION = '2.104';
-}
-# ABSTRACT: the header of an Email::Simple message
+
+use strict;
 use Carp ();
 
 require Email::Simple;
 
+our $VERSION = '2.201';
+$VERSION = eval $VERSION;
+
+=head1 NAME
+
+Email::Simple::Header - the header of an Email::Simple message
+
+=head1 SYNOPSIS
+
+  my $email = Email::Simple->new($text);
+
+  my $header = $email->head;
+  print $header->as_string;
+
+=head1 DESCRIPTION
+
+This method implements the headers of an Email::Simple object.  It is a very
+minimal interface, and is mostly for private consumption at the moment.
+
+=head1 METHODS
+
+=head2 new
+
+  my $header = Email::Simple::Header->new($head, \%arg);
+
+C<$head> is a string containing a valid email header, or a reference to such a
+string.  If a reference is passed in, don't expect that it won't be altered.
+
+Valid arguments are:
+
+  crlf - the header's newline; defaults to CRLF
+
+=cut
 
 # We need to be able to:
 #   * get all values by lc name
@@ -60,6 +89,13 @@ sub _header_to_list {
   return \@headers;
 }
 
+=head2 as_string
+
+  my $string = $header->as_string(\%arg);
+
+This returns a stringified version of the header.
+
+=cut
 
 # RFC 2822, 3.6:
 # ...for the purposes of this standard, header fields SHOULD NOT be reordered
@@ -95,6 +131,12 @@ sub as_string {
   return $header_str;
 }
 
+=head2 header_names
+
+This method returns the unique header names found in this header, in no
+particular order.
+
+=cut
 
 sub header_names {
   my $headers = $_[0]->{headers};
@@ -104,6 +146,12 @@ sub header_names {
     map { $headers->[ $_ * 2 ] } 0 .. int($#$headers / 2);
 }
 
+=head2 header_pairs
+
+This method returns all the field/value pairs in the header, in the order that
+they appear in the header.
+
+=cut
 
 sub header_pairs {
   my ($self) = @_;
@@ -113,6 +161,15 @@ sub header_pairs {
   return @pairs;
 }
 
+=head2 header
+
+  my $first_value = $header->header($field);
+  my @all_values  = $header->header($field);
+
+This method returns the value or values of the given header field.  If the
+named field does not appear in the header, this method returns false.
+
+=cut
 
 sub _str_value { return ref $_[0] ? $_[0][0] : $_[0] }
 
@@ -133,6 +190,15 @@ sub header {
   }
 }
 
+=head2 header_set
+
+  $header->header_set($field => @values);
+
+This method updates the value of the given header.  Existing headers have their
+values set in place.  Additional headers are added at the end.  If no values
+are given to set, the header will be removed from to the message entirely.
+
+=cut
 
 # Header fields are lines composed of a field name, followed by a colon (":"),
 # followed by a field body, and terminated by CRLF.  A field name MUST be
@@ -179,10 +245,15 @@ sub header_set {
   return wantarray ? @data : $data[0];
 }
 
+=head2 crlf
+
+This method returns the newline string used in the header.
+
+=cut
 
 sub crlf { $_[0]->{mycrlf} }
 
-# =method fold
+# =head2 fold
 # 
 #   my $folded = $header->fold($line, \%arg);
 # 
@@ -229,7 +300,7 @@ sub _fold {
   return $folded;
 }
 
-# =method default_fold_at
+# =head2 default_fold_at
 # 
 # This method (provided for subclassing) returns the default length at which to
 # try to fold header lines.  The default default is 78.
@@ -238,7 +309,7 @@ sub _fold {
 
 sub _default_fold_at { 78 }
 
-# =method default_fold_indent
+# =head2 default_fold_indent
 # 
 # This method (provided for subclassing) returns the default string used to
 # indent folded headers.  The default default is a single space.
@@ -247,109 +318,23 @@ sub _default_fold_at { 78 }
 
 sub _default_fold_indent { " " }
 
-1;
+=head1 PERL EMAIL PROJECT
 
-__END__
+This module is maintained by the Perl Email Project
 
-=pod
-
-=head1 NAME
-
-Email::Simple::Header - the header of an Email::Simple message
-
-=head1 VERSION
-
-version 2.104
-
-=head1 SYNOPSIS
-
-  my $email = Email::Simple->new($text);
-
-  my $header = $email->header_obj;
-  print $header->as_string;
-
-=head1 DESCRIPTION
-
-This method implements the headers of an Email::Simple object.  It is a very
-minimal interface, and is mostly for private consumption at the moment.
-
-=head1 METHODS
-
-=head2 new
-
-  my $header = Email::Simple::Header->new($head, \%arg);
-
-C<$head> is a string containing a valid email header, or a reference to such a
-string.  If a reference is passed in, don't expect that it won't be altered.
-
-Valid arguments are:
-
-  crlf - the header's newline; defaults to CRLF
-
-=head2 as_string
-
-  my $string = $header->as_string(\%arg);
-
-This returns a stringified version of the header.
-
-=head2 header_names
-
-This method returns a list of the unique header names found in this header, in
-no particular order.
-
-=head2 header_pairs
-
-  my @pairs = $header->header_pairs;
-  my $first_name  = $pairs[0];
-  my $first_value = $pairs[1];
-
-This method returns a list of all the field/value pairs in the header, in the
-order that they appear in the header.  (Remember: don't try assigning that to a
-hash.  Some fields may appear more than once!)
-
-=head2 header
-
-  my $first_value = $header->header($field);
-  my @all_values  = $header->header($field);
-
-This method returns the value or values of the given header field.  If the
-named field does not appear in the header, this method returns false.
-
-=head2 header_set
-
-  $header->header_set($field => @values);
-
-This method updates the value of the given header.  Existing headers have their
-values set in place.  Additional headers are added at the end.  If no values
-are given to set, the header will be removed from to the message entirely.
-
-=head2 crlf
-
-This method returns the newline string used in the header.
-
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Simon Cozens
-
-=item *
-
-Casey West
-
-=item *
-
-Ricardo SIGNES
-
-=back
+L<http://emailproject.perl.org/>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2003 by Simon Cozens.
+Copyright 2006-2007 by Ricardo SIGNES
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+Copyright 2004 by Casey West
+
+Copyright 2003 by Simon Cozens
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
+
+1;
